@@ -1,5 +1,5 @@
 dc.polr = function(model, values = NULL, sim.count = 1000, conf.int = 0.95, sigma = NULL, set.seed = NULL, values1 = NULL, values2 = NULL,
-                   type = c("any", "simulation", "bootstrap")){
+                   type = c("any", "simulation", "bootstrap"), summary = TRUE){
   
   # check inputs
   if(is.null(values) && (is.null(values1) || is.null(values2))){
